@@ -18,11 +18,14 @@ TERM_PARAMS = {"alacritty": "--working-directory ",
                "cool-retro-term": "--workdir ",
                "deepin-terminal": "--work-directory ",
                "gnome-terminal": "",
+               "guake": "guake --show --new-tab=",
+               "hyper": "",
                "kitty": "--directory ",
                "konsole": "--workdir ",
                "mate-terminal": "--working-directory=",
                "mlterm": "--working-directory=",
                "qterminal": "--workdir ",
+               "st": "-d ",
                "terminator": "--working-directory=",
                "terminology": "--current-directory ",
                "termite": "-d ",
@@ -33,12 +36,15 @@ TERM_PARAMS = {"alacritty": "--working-directory ",
 NEW_TAB_PARAMS = {"alacritty": None,
                   "cool-retro-term": None,
                   "gnome-terminal": "--tab",
+                  "guake": None,
+                  "hyper": None,
                   "deepin-terminal": None,
                   "kitty": None,
                   "konsole": "--new-tab",
                   "mate-terminal": "--tab",
                   "mlterm": None,
                   "qterminal": None,
+                  "st": None,
                   "terminator": "--new-tab",
                   "terminology": None,
                   "termite": None,
